**Example 1: 成功**

 

Input: 

```
tccli iss ListRecordBackupPlanDevices --cli-unfold-argument  \
    --PlanId 12345678-abcd-efgh-ijkl-1234567890abcd
```

Output: 
```
{
    "Response": {
        "Data": {
            "List": null,
            "PageNumber": 0,
            "PageSize": 20,
            "TotalCount": 0
        },
        "RequestId": "f6951e81-bde0-4e2a-9bf2-203f8416eec0"
    }
}
```

